package NewtonsCradle "Package for Newton's Cradle example"
  package Components "Components used in the Newton's Cradle example"
    extends Modelica.Icons.Package;

    model Ball "PlanarMechanics body with eqations for potential and kinetic energy calculations"
      extends PlanarMechanics.Parts.Body;
      parameter Real yoffset = 0.3 "Height offset for potential energy calculation";
      Real Ek, Ep;
    equation
      Ek = 1 / 2 * (m * yoffset ^ 2 + I) * w ^ 2;
      Ep = -planarWorld.g[2] * (r[2] + yoffset) * m;
      annotation(Documentation(info = "<html>

    <p>
Extension of the <a href=\"modelica://PlanarMechanics.Parts.Body\">PlanarMechanics Body</a> model. Contains equations for calculating the potential and kinetic energies of the bodies.
</p></html>"), Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end Ball;

    model Collision "Collision model for two colliding masses"
      extends PlanarMechanics.Interfaces.PartialTwoFrames;
      parameter Modelica.Units.SI.Length sphereDiameter(final min = 0, start = 1.0) "Sphere diameter";
      parameter Modelica.Units.SI.TranslationalSpringConstant c(final min = 0, start = 1.0e7) "Spring constant";
      parameter Modelica.Units.SI.TranslationalDampingConstant d(final min = 0, start = 0) "Damping constant";
      Modelica.Units.SI.Length[2] cc "Vector from center of sphere a to center of sphere b";
      Modelica.Units.SI.Length c_c_dist "Distance between centers of spheres";
      Real[2] fHat_a "Unit vector in direction of contact force at frame_a";
      Modelica.Units.SI.Length contactDepth "Depth of contact between spheres";
      Boolean contact "Spheres are in contact";
      Modelica.Units.SI.Force fMag "Magnitude of contact force (sign convention of frame_a)";
      Modelica.Units.SI.PotentialEnergy Ee "Stored elastic energy during contact";
    equation
      /* Spheres don't have any friction, so no torque is applied to the frames.
   */
      frame_a.t = 0;
      frame_b.t = 0;
      /* Force balance.
   */
      {frame_b.fx, frame_b.fy} + {frame_a.fx, frame_a.fy} = {0.0, 0.0};
      /* Force on frame_a.
   */
      cc = {frame_b.x - frame_a.x, frame_b.y - frame_a.y};
      c_c_dist = Modelica.Math.Vectors.length(cc);
      fHat_a = 1.0 / c_c_dist * cc;
      contactDepth = sphereDiameter - c_c_dist;
      contact = contactDepth > 0;
      fMag = if contact then max(0, c * contactDepth + d * der(contactDepth)) else 0;
      {frame_a.fx, frame_a.fy} = fHat_a * fMag;
      /* Compute energy stored in the contact spring.
   */
      Ee = if contact then 0.5 * c * contactDepth ^ 2 else 0;
      annotation(Documentation(info = "<html>

    <p>
Model for the collision between two PlanarMechanics bodies. Modeled as a stiff spring with a gap. The spring force is only exerted upon the bodies when they are in contact with each other; otherwise, the force is equal to 0. Has the option to add a dampening constant, which corresponds to friction during collision.
</p></html>"), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, grid = {2, 2}, initialScale = 0.1), graphics = {Line(visible = true, points = {{96, 0}, {80, 0}}), Text(visible = true, origin = {2, 14}, extent = {{-142, -142}, {140, -100}}, textString = "%name"), Rectangle(visible = true, fillColor = {255, 255, 255}, lineThickness = 1.5, extent = {{-100, -50}, {100, 50}}), Rectangle(visible = true, origin = {-49.555, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-29.555, -4.081}, {29.555, 4.081}}), Rectangle(visible = true, origin = {50.445, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-29.555, -4.081}, {29.555, 4.081}}), Polygon(visible = true, origin = {-19.948, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, points = {{-9.208, 20}, {18.416, 0}, {-9.208, -20}}), Polygon(visible = true, origin = {20.792, 0}, rotation = -180, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, points = {{-9.208, 20}, {18.416, 0}, {-9.208, -20}})}), Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, grid = {2, 2}), graphics = {Line(points = {{-80, 32}, {-58, 32}, {-43, 2}, {-13, 62}, {17, 2}, {47, 62}, {62, 32}, {80, 32}}, thickness = 0.5), Line(points = {{-68, 32}, {-68, 97}}, color = {128, 128, 128}), Line(points = {{72, 32}, {72, 97}}, color = {128, 128, 128}), Line(points = {{-68, 92}, {72, 92}}, color = {128, 128, 128}), Polygon(points = {{62, 95}, {72, 92}, {62, 89}, {62, 95}}, lineColor = {128, 128, 128}, fillColor = {128, 128, 128}, fillPattern = FillPattern.Solid), Text(extent = {{-20, 72}, {20, 97}}, lineColor = {0, 0, 255}, textString = "phi_rel"), Rectangle(extent = {{-50, -20}, {40, -80}}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid), Line(points = {{-50, -80}, {68, -80}}), Line(points = {{-50, -20}, {68, -20}}), Line(points = {{40, -50}, {80, -50}}), Line(points = {{-80, -50}, {-50, -50}}), Line(points = {{-80, 32}, {-80, -50}}), Line(points = {{80, 32}, {80, -50}}), Line(points = {{-96, 0}, {-80, 0}}), Line(points = {{96, 0}, {80, 0}})}));
    end Collision;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = false, initialScale = 0.1, grid = {10, 10})), Documentation, Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end Components;

  model NewtonsCradleModel "Newton's cradle example setup using PlanarMechanics"
    extends Modelica.Icons.Example;
    import from_deg = Modelica.Units.Conversions.from_deg;
    inner PlanarMechanics.PlanarWorld planarWorld(defaultZPosition = 0, animateWorld = false, animateGravity = false) annotation(Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Modelica.Units.SI.TranslationalSpringConstant impactc = 1e8 "Impact stiffness";
    parameter Modelica.Units.SI.TranslationalDampingConstant impactd = 0 "Impact friction";
    parameter Modelica.Units.SI.Angle phi0(displayUnit = "deg") = 1.39626340159546 "Initial angle of ball 1";
    PlanarMechanics.Parts.Fixed fixed1(r = {0, 0}) annotation(Placement(visible = true, transformation(origin = {-80, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    PlanarMechanics.Parts.Fixed fixed2(r = {0.10, 0}) annotation(Placement(visible = true, transformation(origin = {-40, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    PlanarMechanics.Parts.Fixed fixed3(r = {0.20, 0}) annotation(Placement(visible = true, transformation(origin = {-0, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    PlanarMechanics.Parts.Fixed fixed4(r = {0.30, 0}) annotation(Placement(visible = true, transformation(origin = {40, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    PlanarMechanics.Parts.Fixed fixed5(r = {0.40, 0}) annotation(Placement(visible = true, transformation(origin = {80, 60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    PlanarMechanics.Joints.Revolute revolute1 annotation(Placement(visible = true, transformation(origin = {-80, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Joints.Revolute revolute2 annotation(Placement(visible = true, transformation(origin = {-40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Joints.Revolute revolute3 annotation(Placement(visible = true, transformation(origin = {-0, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Joints.Revolute revolute4 annotation(Placement(visible = true, transformation(origin = {40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Joints.Revolute revolute5 annotation(Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Parts.FixedTranslation rope1(r = {0.3, 0}) annotation(Placement(visible = true, transformation(origin = {-80, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Parts.FixedTranslation rope2(r = {0.3, 0}) annotation(Placement(visible = true, transformation(origin = {-40, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Parts.FixedTranslation rope3(r = {0.3, 0}) annotation(Placement(visible = true, transformation(origin = {-0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Parts.FixedTranslation rope4(r = {0.3, 0}) annotation(Placement(visible = true, transformation(origin = {40, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    PlanarMechanics.Parts.FixedTranslation rope5(r = {0.3, 0}) annotation(Placement(visible = true, transformation(origin = {80, -20}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Components.Ball ball1(phi.start = from_deg(270) - phi0, m = 10, I = 1, sphereDiameter = sphereDiameter, phi.fixed = true, phi.displayUnit = "deg") annotation(Placement(visible = true, transformation(origin = {-80, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Components.Ball ball2(phi.start = -1.5707963267949, m = 10, I = 1, sphereDiameter = sphereDiameter, phi.fixed = true) annotation(Placement(visible = true, transformation(origin = {-40, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Components.Ball ball3(phi.start = -1.5707963267949, m = 10, I = 1, sphereDiameter = sphereDiameter, phi.fixed = true) annotation(Placement(visible = true, transformation(origin = {-0, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Components.Ball ball4(phi.start = -1.5707963267949, m = 10, I = 1, sphereDiameter = sphereDiameter, phi.fixed = true) annotation(Placement(visible = true, transformation(origin = {40, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Components.Ball ball5(phi.start = -1.5707963267949, m = 10, I = 1, sphereDiameter = sphereDiameter, phi.fixed = true) annotation(Placement(visible = true, transformation(origin = {80, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    NewtonsCradle.Components.Collision collision1_2(c = impactc, d = impactd, sphereDiameter = sphereDiameter) annotation(Placement(visible = true, transformation(origin = {-60, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    NewtonsCradle.Components.Collision collision2_3(c = impactc, d = impactd, sphereDiameter = sphereDiameter) annotation(Placement(visible = true, transformation(origin = {-20, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    NewtonsCradle.Components.Collision collision3_4(c = impactc, d = impactd, sphereDiameter = sphereDiameter) annotation(Placement(visible = true, transformation(origin = {20, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    NewtonsCradle.Components.Collision collision4_5(c = impactc, d = impactd, sphereDiameter = sphereDiameter) annotation(Placement(visible = true, transformation(origin = {60, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Units.SI.KineticEnergy totalKineticEnergy "Sum of kinetic energy in all balls";
    Modelica.Units.SI.PotentialEnergy totalElasticEnergy "Sum of elastic energy in all collisions";
    Modelica.Units.SI.PotentialEnergy totalKineticAndElasticEnergy = totalKineticEnergy + totalElasticEnergy "Sum of kinetic and elastic energy in all balls and collisions";
    Modelica.Units.SI.PotentialEnergy totalPotentialEnergy "Sum of potential energy in all balls";
    Modelica.Units.SI.Energy totalEnergy "Sum of kinetic, elastic and potential energy in all balls and collisions";
  protected
    constant Modelica.Units.SI.Length sphereDiameter = 0.099 "Sphere diameter";
  equation
    assert(phi0 >= 0 and phi0 <= from_deg(180), "Initial angle of ball 1 (phi0) needs to be set between 0° and 180°.");
    assert(impactc >= 1e4 and impactc <= 1e14, "Impact stiffness(impactc) needs to be set between 10^4 and 10^14.");
    connect(collision4_5.frame_b, ball5.frame_a) annotation(Line(visible = true, origin = {76.667, -43.333}, points = {{-6.667, 3.333}, {3.333, 3.333}, {3.333, -6.667}}, color = {95, 95, 95}));
    connect(collision4_5.frame_a, ball4.frame_a) annotation(Line(visible = true, origin = {43.333, -43.333}, points = {{6.667, 3.333}, {-3.333, 3.333}, {-3.333, -6.667}}, color = {95, 95, 95}));
    connect(collision3_4.frame_b, ball4.frame_a) annotation(Line(visible = true, origin = {36.667, -43.333}, points = {{-6.667, 3.333}, {3.333, 3.333}, {3.333, -6.667}}, color = {95, 95, 95}));
    connect(ball3.frame_a, collision3_4.frame_a) annotation(Line(visible = true, origin = {3.333, -43.333}, points = {{-3.333, -6.667}, {-3.333, 3.333}, {6.667, 3.333}}, color = {95, 95, 95}));
    connect(fixed4.frame, revolute4.frame_a) annotation(Line(visible = true, origin = {40, 40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(revolute4.frame_b, rope4.frame_a) annotation(Line(visible = true, origin = {40, 0}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(rope4.frame_b, ball4.frame_a) annotation(Line(visible = true, origin = {40, -40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(rope5.frame_b, ball5.frame_a) annotation(Line(visible = true, origin = {80, -40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(revolute5.frame_b, rope5.frame_a) annotation(Line(visible = true, origin = {80, 0}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(fixed5.frame, revolute5.frame_a) annotation(Line(visible = true, origin = {80, 40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(collision2_3.frame_a, ball2.frame_a) annotation(Line(visible = true, origin = {-43.333, -36.667}, points = {{13.333, -3.333}, {3.333, -3.333}, {3.333, -13.333}}, color = {95, 95, 95}));
    connect(rope3.frame_b, ball3.frame_a) annotation(Line(visible = true, origin = {0, -40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(revolute3.frame_b, rope3.frame_a) annotation(Line(visible = true, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(fixed3.frame, revolute3.frame_a) annotation(Line(visible = true, origin = {0, 40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(ball3.frame_a, collision2_3.frame_b) annotation(Line(visible = true, origin = {-3.333, -43.333}, points = {{3.333, -6.667}, {3.333, 3.333}, {-6.667, 3.333}}, color = {95, 95, 95}));
    connect(ball2.frame_a, collision1_2.frame_b) annotation(Line(visible = true, origin = {-43.333, -43.333}, points = {{3.333, -6.667}, {3.333, 3.333}, {-6.667, 3.333}}, color = {95, 95, 95}));
    connect(ball1.frame_a, collision1_2.frame_a) annotation(Line(visible = true, origin = {-76.667, -43.333}, points = {{-3.333, -6.667}, {-3.333, 3.333}, {6.667, 3.333}}, color = {95, 95, 95}));
    connect(fixed2.frame, revolute2.frame_a) annotation(Line(visible = true, origin = {-40, 40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(revolute2.frame_b, rope2.frame_a) annotation(Line(visible = true, origin = {-40, 0}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(rope2.frame_b, ball2.frame_a) annotation(Line(visible = true, origin = {-40, -40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(rope1.frame_b, ball1.frame_a) annotation(Line(visible = true, origin = {-80, -40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(revolute1.frame_b, rope1.frame_a) annotation(Line(visible = true, origin = {-80, 0}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    connect(fixed1.frame, revolute1.frame_a) annotation(Line(visible = true, origin = {-80, 40}, points = {{0, 10}, {0, -10}}, color = {95, 95, 95}));
    totalKineticEnergy = ball1.Ek + ball2.Ek + ball3.Ek + ball4.Ek + ball5.Ek;
    totalPotentialEnergy = ball1.Ep + ball2.Ep + ball3.Ep + ball4.Ep + ball5.Ep;
    totalElasticEnergy = collision1_2.Ee + collision2_3.Ee + collision3_4.Ee + collision4_5.Ee;
    totalEnergy = totalKineticEnergy + totalPotentialEnergy + totalElasticEnergy;
    annotation(preferredView = "info", experiment(StartTime = 0.0, StopTime = 5, __Wolfram_NumberOfIntervals = -1, __Wolfram_Algorithm = "dassl", Tolerance = 1e-7, __Wolfram_CheckMinMax = true), __Wolfram(ControlPanels(Panel(identifier = "wonderful-erdos", title = "Model parameters", elements = {InputField(variable = impactc, label = "Impact stiffness"), InputField(variable = impactd, label = "Impact friction"), InputField(variable = phi0, label = "Initial angle of ball 1")})), Animation(windows = {Window(name = "Default", groundGrid = false, camera = "Default")}, cameras = {Camera(name = "Default", center = {0.1984728425741196, -0.103856235742569, 0}, distance = 2.383848667144775, rotation = {0, 0, 0, 1})})), Documentation(info = "<html>
<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/planar-mechanics/\">PlanarMechanics</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/PlanarMechanics.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px; \">The free PlanarMechanics library was created especially for modeling multibody systems with two-dimensional mechanical components. Compared to the MultiBody library, currently available in the Modelica Standard Library, it is simpler to use and it is more optimized to planar modeling. Planar models of mechanical systems are useful in many different applications, for example, in contact problems that are more easily modeled in 2D than in 3D.</li>

	</ul>
</div>

<h4>Model</h4>
    <p>
This model shows the Newton's Cradle experiment.
</p>

    <p>
 Five spheres are connected to a revolute joint through a stiff rod and hung next to each other. One of the spheres is released at an angle of 80 degrees, and gravity will pull it downward in a swinging motion, which will lead the sphere to collide with the adjacent sphere.
</p><p>
The <a href=\"modelica://NewtonsCradle.Components.Collision\">collision</a> between the spheres is modeled as a spring with a gap.
</p>

    <h4>Automatic 3D Animation</h4>
    <p>
Multibody and PlanarMechanics systems have visualizers to show what a real-world system would look like.
</p><p>
To show a 3D animation of the model, follow the steps below:
</p>

<p>Click the Simulate button: <img src=\"modelica://NewtonsCradle/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<p>Click the Animation button: <img src=\"modelica://NewtonsCradle/DocumentationFiles/animate.svg\" style=\"width:20px\" alt=\"animate\" /></p>
<p>Use your mouse or trackpad to drag the animation to a good angle and zoom in with your scroll wheel or by using the trackpad. Then click the Play button: <img src=\"modelica://NewtonsCradle/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"play\" /></p>

<h4>Plot the Results</h4>
    <p>
Explore how the energy is conserved in the system. When first simulating the model, you will see the following plot:
</p>
<p style=\"text-align: center;\"><img src=\"modelica://NewtonsCradle/DocumentationFiles/defaultplot.png\" style=\"width:600px\" alt=\"\" /></p>
<p>
 Also try plotting the <span>Ball Positions</span> plot to see a parametric plot of the ball trajectories, or the <span>All Energy Types</span> to see how kinetic energy is temporaraly stored as elastic energy during collisions.
</p>
<p style=\"text-align: center;\"><img src=\"modelica://NewtonsCradle/DocumentationFiles/allenergytypes.png\" style=\"width:600px\" alt=\"\" /></p>
<h3>Change Parameters</h3>
    <p>
Changing parameters for the simulation can be done rapidly in Simulation Center. The <span>impactd</span> parameter describes the energy that is lost due to friction when the balls collide with each other. The default value for this parameter is 0, which means that no energy is lost due to collisions.
</p><p>
Try changing the  <span>impactd</span> parameter to see how it affects the system:
</p><ul><li>Switch to the <span>Parameter</span> tab on the left in the Experiment Browser.</li><li>Scroll down to the <span>impactd</span> parameter and change its value to 1000 by typing into the box to the right of the parameter.</li><li>Simulate again by following the steps in the Automatic 3D Animation and Plot sections to see the effects of your changes.</li></ul><p>
Also try changing the <span>impactc</span> parameter to make collisions more or less stiff, or change the <span>phi0</span> to change the initial angle of the ball.
</p>


</html>", figures = {Figure(title = "Energy plot", identifier = "e49b2", preferred = true, plots = {Plot(curves = {Curve(y = totalEnergy, legend = "Total Energy"), Curve(y = totalKineticAndElasticEnergy, legend = "Total Kinetic and Elastic Energy"), Curve(y = totalPotentialEnergy, legend = "Total Potential Energy")})}), Figure(title = "All energy types", identifier = "22167", plots = {Plot(curves = {Curve(y = totalElasticEnergy, legend = "Elastic Energy"), Curve(y = totalKineticEnergy, legend = "Kinetic Energy"), Curve(y = totalPotentialEnergy, legend = "Potential Energy")})}), Figure(title = "Ball positions", identifier = "507d4", plots = {Plot(curves = {Curve(x = ball1.r[1], y = ball1.r[2], legend = "Ball 1"), Curve(x = ball2.r[1], y = ball2.r[2], legend = "Ball 2"), Curve(x = ball3.r[1], y = ball3.r[2], legend = "Ball 3"), Curve(x = ball4.r[1], y = ball4.r[2], legend = "Ball 4"), Curve(x = ball5.r[1], y = ball5.r[2], legend = "Ball 5")})}), Figure(title = "Angle and angular velocity", identifier = "aad43", plots = {Plot(curves = {Curve(y = revolute1.phi, legend = "Ball 1 Angle"), Curve(y = revolute5.phi, legend = "Ball 5 Angle")}), Plot(curves = {Curve(y = revolute1.w, legend = "Ball 1 Angular Velocity"), Curve(y = revolute5.w, legend = "Ball 5 Angular Velocity")})}), Figure(title = "Contact", identifier = "e7eb6", plots = {Plot(curves = {Curve(y = collision1_2.contact, legend = "1-2 Collision"), Curve(y = collision2_3.contact, legend = "2-3 Collision"), Curve(y = collision3_4.contact, legend = "3-4 Collision"), Curve(y = collision4_5.contact, legend = "4-5 Collision")})})}), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = false, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end NewtonsCradleModel;
  annotation(Documentation(info = "<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/planar-mechanics/\">PlanarMechanics</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/PlanarMechanics.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px;\">The free PlanarMechanics library was created especially for modeling multibody systems with two-dimensional mechanical components. Compared to the MultiBody library, currently available in the Modelica Standard Library, it is simpler to use and it is more optimized to planar modeling. Planar models of mechanical systems are useful in many different applications, for example, in contact problems that are more easily modeled in 2D than in 3D.</li>

	</ul>
</div>"), preferredView = "info", uses(PlanarMechanics(version = "1.6.0"), Modelica(version = "4.0.0")), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, origin = {0, -1.5}, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 19.333}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), __Wolfram(openClass = NewtonsCradle.NewtonsCradleModel));
end NewtonsCradle;
